#
# spec file for package flash-player
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           flash-player
Version:        32.0.0.465
Release:        1699.3.pm.32
Summary:        Adobe Flash Standalone Player
License:        NonFree
URL:            https://get.adobe.com/flashplayer
%ifarch %{ix86}
Source0:        flash_player_sa_11.2.202.644_linux.i386.tar.gz
%endif
%ifarch x86_64
Source0:        https://fpdownload.macromedia.com/pub/labs/flashruntimes/flashplayer/linux64/flash_player_sa_linux.x86_64.tar.gz#/flash_player_sa_%{version}_linux.x86_64.tar.gz
%endif
Source1:        flashplayer.desktop
Source2:        flashplayer.png
BuildRequires:  hicolor-icon-theme
BuildRequires:  update-desktop-files
# Flash Player dynamically opens that one and segfaults if not available (2008-11-12).
Requires:       libasound2%{?_isa}
Requires:       libcurl4%{?_isa}
ExclusiveArch:  %ix86 x86_64

%description
This package contains Adobe's Flash Player application.

%prep
%setup -q -c

cp -f %{SOURCE1} flashplayer.desktop
cp -f %{SOURCE2} flashplayer.png

%build
# Nothing to build.

%install
install -Dpm 0755 flashplayer %{buildroot}%{_bindir}/flashplayer
install -Dpm 0644 flashplayer.desktop \
  %{buildroot}%{_datadir}/applications/flashplayer.desktop
install -Dpm 0644 flashplayer.png %{buildroot}%{_datadir}/pixmaps/flashplayer.png

%suse_update_desktop_file flashplayer

%post
%ifarch %ix86
# This is an ugly hack: flash-player hard-requires SSE2. Neither
# rpm nor zypper can limit installation to SSE2 equipped systems
# only. We have to choose one of two bad things: install and let it
# crash or install and deliberately break it. The second is done
# here (boo#856386).
if ( ! grep -q '^flags.*sse2' /proc/cpuinfo ); then
    rm -f %{_bindir}/flashplayer
    echo "Flash Player requires a CPU with SSE2. It cannot work on your system." >&2
    echo "Please, uninstall it!" >&2
fi
%endif

%files
%ifarch x86_64
%license LGPL/ license.pdf
%endif
%{_bindir}/flashplayer
%{_datadir}/applications/flashplayer.desktop
%{_datadir}/pixmaps/flashplayer.png

%changelog
* Sun Jan 10 2021 Alexei Sorokin <sor.alexei@meowr.ru>
- Remove the plug-in from packaging as it no longer works.
- Remove plash-player-gnome: properties are intended for the
  plug-in and are packaged with the NPAPI plug-in.
- Remove flash-player-desktop.patch.
* Tue Dec  8 2020 Luigi Baldoni <aloisio@gmx.com>
- Update to version 32.0.0.465
  * Final release.
* Tue Nov 10 2020 aloisio@gmx.com
- Update to version 32.0.0.453
  * Important bug fixes.
* Mon Oct 12 2020 Alexei Sorokin <sor.alexei@meowr.ru>
- Update to version 32.0.0.445:
  * Assorted security and functional fixes.
  * APSB20-58, CVE-2020-9746.
* Tue Sep  8 2020 aloisio@gmx.com
- Update to version 32.0.0.433
  * Assorted security and functional fixes.
* Wed Aug 26 2020 aloisio@gmx.com
- Update to version 32.0.0.414
  * Assorted functional fixes.
* Thu Jul 23 2020 Luigi Baldoni <aloisio@gmx.com>
- Update to version 32.0.0.403
  * Assorted functional fixes.
- Fixes boo#1174402
* Tue Jun  9 2020 Alexei Sorokin <sor.alexei@meowr.ru>
- Update to version 32.0.0.387:
  * APSB20-30, CVE-2020-9633.
  * Assorted security and functional fixes.
* Tue Apr 28 2020 enzokiel@kabelmail.de
- Update to version 32.0.0.363:
  * Assorted functional fixes.
* Wed Mar 18 2020 Dave Plater <davejplater@gmail.com>
- Update to version 32.0.0.344:
  * Assorted functional fixes.
* Tue Feb 11 2020 Alexei Sorokin <sor.alexei@meowr.ru>
- Update to version 32.0.0.330:
  * APSB20-06, CVE-2020-3757.
* Sun Feb  2 2020 Stefan Seyfried <seife+obs@b1-systems.com>
- Update to version 32.0.0.314:
  * Assorted functional fixes.
* Tue Dec 31 2019 Luigi Baldoni <aloisio@gmx.com>
- Update to version 32.0.0.303:
  * Assorted functional fixes.
* Fri Nov  1 2019 Luigi Baldoni <aloisio@gmx.com>
- Update to version 32.0.0.270:
  * Assorted functional fixes.
- Spec cleanup
* Tue Sep 10 2019 Alexei Sorokin <sor.alexei@meowr.ru>
- Update to version 32.0.0.255:
  * APSB19-46, CVE-2019-8070, CVE-2019-8069.
  * Assorted functional and security fixes.
* Mon Aug 19 2019 enzokiel@kabelmail.de
- Update to version 32.0.0.238:
  * Assorted functional fixes.
* Sat Aug  3 2019 enzokiel@kabelmail.de
- Update to version 32.0.0.223:
  * Assorted functional fixes
* Tue Jun 11 2019 Alexei Sorokin <sor.alexei@meowr.ru>
- Security update to version 32.0.0.207:
  * APSB19-30, CVE-2019-7845.
* Tue May 14 2019 Alexei Sorokin <sor.alexei@meowr.ru>
- Security update to version 32.0.0.192:
  * APSB19-26, CVE-2019-7837.
* Tue Apr  9 2019 Alexei Sorokin <sor.alexei@meowr.ru>
- Security update to version 32.0.0.171:
  * APSB19-19, CVE-2019-7096, CVE-2019-7108.
  * Assorted security and functional fixes.
* Tue Mar 12 2019 Alexei Sorokin <sor.alexei@meowr.ru>
- Update to version 32.0.0.156:
  * Assorted security and functional fixes.
* Tue Feb 12 2019 Alexei Sorokin <sor.alexei@meowr.ru>
- Security update to version 32.0.0.142:
  * APSB19-06, CVE-2019-7090.
  * Assorted security and functional fixes.
* Tue Jan  8 2019 Alexei Sorokin <sor.alexei@meowr.ru>
- Update to version 32.0.0.114:
  * APSB19-01.
  * Fix feature and performance bugs.
* Wed Dec  5 2018 Alexei Sorokin <sor.alexei@meowr.ru>
- Security update to version 32.0.0.101:
  * APSB18-42, CVE-2018-15982, CVE-2018-15983.
  * Assorted security and functional fixes.
* Tue Nov 20 2018 Alexei Sorokin <sor.alexei@meowr.ru>
- Security update to version 31.0.0.153:
  * APSB18-44, CVE-2018-15981.
* Tue Nov 13 2018 Alexei Sorokin <sor.alexei@meowr.ru>
- Security update to version 31.0.0.148:
  * APSB18-39, CVE-2018-15978.
  * Assorted security and functional fixes.
* Tue Sep 11 2018 Alexei Sorokin <sor.alexei@meowr.ru>
- Security update to version 31.0.0.108:
  * APSB18-31, CVE-2018-15967.
  * Assorted security and functional fixes.
* Tue Aug 14 2018 Alexei Sorokin <sor.alexei@meowr.ru>
- Security update to version 30.0.0.154:
  * APSB18-25, CVE-2018-12824, CVE-2018-12825, CVE-2018-12826,
    CVE-2018-12827, CVE-2018-12828.
  * Flash Player quits unexpectedly when changing the audio output
    through system sound panel.
  * Assorted security and functional fixes.
* Tue Jul 10 2018 Alexei Sorokin <sor.alexei@meowr.ru>
- Security update to version 30.0.0.134:
  * APSB18-24, CVE-2018-5008, CVE-2018-5007.
  * Assorted security and functional fixes.
* Thu Jun  7 2018 Alexei Sorokin <sor.alexei@meowr.ru>
- Security update to version 30.0.0.113:
  * APSB18-19, CVE-2018-4945, CVE-2018-5000, CVE-2018-5001,
    CVE-2018-5002.
  * Host cannot promote Participants into Host or Presenter role in
    a Connect Meeting.
* Tue May  8 2018 Alexei Sorokin <sor.alexei@meowr.ru>
- Security update to version 29.0.0.171:
  * APSB18-16, CVE-2018-4944.
  * Gradients in static SWFs showed "Movie Not Loaded" in
    Flash Player.
* Tue Apr 10 2018 Alexei Sorokin <sor.alexei@meowr.ru>
- Security update to version 29.0.0.140:
  * APSB18-08, CVE-2018-4932, CVE-2018-4933, CVE-2018-4934,
    CVE-2018-4935, CVE-2018-4936, CVE-2018-4937.
  * Multiple security and functional fixes.
* Tue Mar 13 2018 Alexei Sorokin <sor.alexei@meowr.ru>
- Security update to version 29.0.0.113:
  * APSB18-05, CVE-2018-4919, CVE-2018-4920.
  * Fix Flash Player settings panel become unresponsive when
    hardware acceleration is turned off on Firefox.
  * Fix Flash Player quitting unexpectedly when the
    "by.blooddy.crypto.Base64" class tries to decode BASE64.
  * Flash Player Protected mode + asynch drawing on Firefox causes
    the font colour to be inverted.
  * SecureSocket and RTMPS with OpenSSL was not sending
    "server_name" SNI headers.
  * Flash Player did not connect via SecureSocket to a server
    running only TLS1.2.
* Tue Feb  6 2018 Alexei Sorokin <sor.alexei@meowr.ru>
- Security update to version 28.0.0.161:
  * APSB18-03, CVE-2018-4878, CVE-2018-4877.
  * Important bug fixes and security updates.
- Rename desktop.diff to flash-player-desktop.patch.
* Wed Jan 10 2018 Alexei Sorokin <sor.alexei@meowr.ru>
- Security update to version 28.0.0.137:
  * APSB18-01, CVE-2018-4871.
  * Assorted security and functional fixes.
* Tue Dec 12 2017 Alexei Sorokin <sor.alexei@meowr.ru>
- Update to version 28.0.0.126:
  * APSB17-42, CVE-2017-11305.
  * A memory leak is observed when running a Stage3D application
    using Baseline_Constrained profile.
  * The file upload dialogue becomes unresponsive on Chromium when
    using the Scratch editor.
  * The volume slider is not visible when playing the video from
    https://www.vudu.com/movies/#!content/74336/CHUD-2-Bud-The-Chud
    in full screen mode.
* Tue Nov 14 2017 Alexei Sorokin <sor.alexei@meowr.ru>
- Security update to version 27.0.0.187:
  * APSB17-33, CVE-2017-3112, CVE-2017-3114, CVE-2017-11213,
    CVE-2017-11215, CVE-2017-11225.
  * LoadMovie on layers other than 0 causes access violation in
    C# WinForms.
  * Flash Player quits unexpectedly before the content is loaded in
    certain cases.
* Mon Oct 16 2017 Alexei Sorokin <sor.alexei@meowr.ru>
- Security update to version 27.0.0.170:
  * APSB17-32, CVE-2017-11292.
* Tue Sep 12 2017 Alexei Sorokin <sor.alexei@meowr.ru>
- Update to version 27.0.0.130:
  * APSB17-28, CVE-2017-11281, CVE-2017-11282.
  * The application behaved abnormally when spacebar is pressed in
    the Text Field.
  * Audio output selection support.
  * ActionScript API for Audio Device Manager support.
* Tue Aug  8 2017 Alexei Sorokin <sor.alexei@meowr.ru>
- Security update to version 26.0.0.151:
  * APSB17-23, CVE-2017-3085, CVE-2017-3106.
  * Graphics vector assets are not rendering properly.
* Tue Jul 11 2017 Alexei Sorokin <sor.alexei@meowr.ru>
- Security update to version 26.0.0.137:
  * APSB17-21, CVE-2017-3080, CVE-2017-3099, CVE-2017-3100.
  * FileReference size and creationDate throws IO Error.
* Fri Jun 16 2017 Alexei Sorokin <sor.alexei@meowr.ru>
- Update to version 26.0.0.131:
  * Buttons can't be clicked in some AS2 content.
* Tue Jun 13 2017 Alexei Sorokin <sor.alexei@meowr.ru>
- Security update to version 26.0.0.126:
  * APSB17-17, CVE-2017-3075, CVE-2017-3081, CVE-2017-3083,
    CVE-2017-3084, CVE-2017-3076, CVE-2017-3077, CVE-2017-3078,
    CVE-2017-3079, CVE-2017-3082.
  * removeMovieClip() method was not working as expected.
  * http://catalog.kaientai.cc viewer application was quitting
    unexpectedly.
  * Video was quitting unexpectedly while playing from
    http://tw.youvivid.com/preview_showcase.asp
  * Flash Player was quitting unexpectedly upon interaction with
    site tabs.
  * FileReference size and creationDate throwed an IO Error.
* Tue May  9 2017 Alexei Sorokin <sor.alexei@meowr.ru>
- Security update to version 25.0.0.171:
  * Important bug fixes.
  * APSB17-15, CVE-2017-3068, CVE-2017-3069, CVE-2017-3070,
    CVE-2017-3071, CVE-2017-3072, CVE-2017-3073, CVE-2017-3074.
* Tue Apr 11 2017 Alexei Sorokin <sor.alexei@meowr.ru>
- Security update to version 25.0.0.148:
  * Important bug fixes.
  * APSB17-10, CVE-2017-3058, CVE-2017-3059, CVE-2017-3060,
    CVE-2017-3061, CVE-2017-3062, CVE-2017-3063, CVE-2017-3064.
* Tue Mar 14 2017 Alexei Sorokin <sor.alexei@meowr.ru>
- Update to version 25.0.0.127:
  * Pressing Space bar in the Text Field makes the app behave
    abnormally.
  * Flash Player 24.0.0.221 quits unexpectedly.
  * Wacom tablet click inputs don't work with Chromium 55.
  * Multiple functional fixes.
  * APSB17-07, CVE-2017-2997, CVE-2017-2998, CVE-2017-2999,
    CVE-2017-3000, CVE-2017-3001, CVE-2017-3002, CVE-2017-3003.
* Tue Feb 14 2017 Alexei Sorokin <sor.alexei@meowr.ru>
- Security update to version 24.0.0.221:
  * Multiple functional fixes.
  * APSB17-04, CVE-2017-2982, CVE-2017-2984, CVE-2017-2985,
    CVE-2017-2986, CVE-2017-2987, CVE-2017-2988, CVE-2017-2990,
    CVE-2017-2991, CVE-2017-2992, CVE-2017-2993, CVE-2017-2994,
    CVE-2017-2995, CVE-2017-2996.
* Tue Jan 10 2017 Alexei Sorokin <sor.alexei@meowr.ru>
- Security update to version 24.0.0.194 (bsc#1019129):
  * Event handler Event.CONNECT is not called when using
    flash.net.Socket to connect the server.
  * APSB17-02, CVE-2017-2925, CVE-2017-2926, CVE-2017-2927,
    CVE-2017-2928, CVE-2017-2930, CVE-2017-2931, CVE-2017-2932,
    CVE-2017-2933, CVE-2017-2934, CVE-2017-2935, CVE-2017-2936,
    CVE-2017-2937, CVE-2017-2938.
* Wed Dec 14 2016 Alexei Sorokin <sor.alexei@meowr.ru>
- Separate PPAPI plugin into flash-player-ppapi: merged package
  creates issues for freshplayerplugin.
* Tue Dec 13 2016 Alexei Sorokin <sor.alexei@meowr.ru>
- Update to version 24.0.0.186 (bsc#1015379):
  * Enabling async drawing shows boundaries for transparent object.
  * Worker is taking more time to write object in a shared byte
    array.
  * "ALT GR+0" does not return "@" on a French layout Keyboard.
  * Blank screen is observed until a mouse click is received after
    enabling Async drawing.
  * Scaling the swf does not trigger a corresponding scaling of the
    hit area of elements in the browser.
  * Flash Player quits unexpectedly while playing
    http://www.evil3d.cn/example/.
  * A black screen is observed when video is seeking on Chromium.
  * Seek bar does not appear on hovering mouse cursor on a video.
  * Action Script is unable to handle MOUSE_MOVE events.
  * APSB16-39, CVE-2016-7867, CVE-2016-7868, CVE-2016-7869,
    CVE-2016-7870, CVE-2016-7871, CVE-2016-7872, CVE-2016-7873,
    CVE-2016-7874, CVE-2016-7875, CVE-2016-7876, CVE-2016-7877,
    CVE-2016-7878, CVE-2016-7879, CVE-2016-7880, CVE-2016-7881,
    CVE-2016-7890, CVE-2016-7892.
- Merge chromium-pepper-flash into this package (PPAPI plugin).
- Own /usr/lib64/browser-plugins/.
- Package the 24px flash-player-properties icon.
- Remove Flash_Player_12_0.pdf: package license.pdf instead.
* Tue Nov  8 2016 Alexei Sorokin <sor.alexei@meowr.ru>
- Security update to version 11.2.202.644 (bsc#1009217):
  * APSB16-37, CVE-2016-7857, CVE-2016-7858, CVE-2016-7859,
    CVE-2016-7860, CVE-2016-7861, CVE-2016-7862, CVE-2016-7863,
    CVE-2016-7864, CVE-2016-7865.
* Wed Oct 26 2016 Alexei Sorokin <sor.alexei@meowr.ru>
- Security update to version 11.2.202.643 (bsc#1007098):
  * APSB16-36, CVE-2016-7855.
* Tue Oct 11 2016 Alexei Sorokin <sor.alexei@meowr.ru>
- Security update to version 11.2.202.637 (bsc#1004019):
  * APSB16-32, CVE-2016-4273, CVE-2016-4286, CVE-2016-6981,
    CVE-2016-6982, CVE-2016-6983, CVE-2016-6984, CVE-2016-6985,
    CVE-2016-6986, CVE-2016-6987, CVE-2016-6989, CVE-2016-6990,
    CVE-2016-6992.
* Mon Sep 19 2016 Alexei Sorokin <sor.alexei@meowr.ru>
- Security update to version 11.2.202.635 (bsc#998589):
  * APSB16-29, CVE-2016-4182, CVE-2016-4237, CVE-2016-4238,
    CVE-2016-4271, CVE-2016-4272, CVE-2016-4274, CVE-2016-4275,
    CVE-2016-4276, CVE-2016-4277, CVE-2016-4278, CVE-2016-4279,
    CVE-2016-4280, CVE-2016-4281, CVE-2016-4282, CVE-2016-4283,
    CVE-2016-4284, CVE-2016-4285, CVE-2016-4287, CVE-2016-6921,
    CVE-2016-6922, CVE-2016-6923, CVE-2016-6924, CVE-2016-6925,
    CVE-2016-6926, CVE-2016-6927, CVE-2016-6929, CVE-2016-6930,
    CVE-2016-6931, CVE-2016-6932.
- Use licence file for the correct Flash version.
* Wed Jul 20 2016 Alexei Sorokin <sor.alexei@meowr.ru>
- Security update to version 11.2.202.632 (bsc#988579):
  * APSB16-25, CVE-2016-4172, CVE-2016-4173, CVE-2016-4174,
    CVE-2016-4175, CVE-2016-4176, CVE-2016-4177, CVE-2016-4178,
    CVE-2016-4179, CVE-2016-4180, CVE-2016-4181, CVE-2016-4182,
    CVE-2016-4183, CVE-2016-4184, CVE-2016-4185, CVE-2016-4186,
    CVE-2016-4187, CVE-2016-4188, CVE-2016-4189, CVE-2016-4190,
    CVE-2016-4217, CVE-2016-4218, CVE-2016-4219, CVE-2016-4220,
    CVE-2016-4221, CVE-2016-4222, CVE-2016-4223, CVE-2016-4224,
    CVE-2016-4225, CVE-2016-4226, CVE-2016-4227, CVE-2016-4228,
    CVE-2016-4229, CVE-2016-4230, CVE-2016-4231, CVE-2016-4232,
    CVE-2016-4233, CVE-2016-4234, CVE-2016-4235, CVE-2016-4236,
    CVE-2016-4237, CVE-2016-4238, CVE-2016-4239, CVE-2016-4240,
    CVE-2016-4241, CVE-2016-4242, CVE-2016-4243, CVE-2016-4244,
    CVE-2016-4245, CVE-2016-4246, CVE-2016-4247, CVE-2016-4248,
    CVE-2016-4249.
* Fri Jun 17 2016 Alexei Sorokin <sor.alexei@meowr.ru>
- Security update to version 11.2.202.626 (bsc#984695):
  * APSA16-03, APSB16-18, CVE-2016-4122, CVE-2016-4123,
    CVE-2016-4124, CVE-2016-4125, CVE-2016-4127, CVE-2016-4128,
    CVE-2016-4129, CVE-2016-4130, CVE-2016-4131, CVE-2016-4132,
    CVE-2016-4133, CVE-2016-4134, CVE-2016-4135, CVE-2016-4136,
    CVE-2016-4137, CVE-2016-4138, CVE-2016-4139, CVE-2016-4140,
    CVE-2016-4141, CVE-2016-4142, CVE-2016-4143, CVE-2016-4144,
    CVE-2016-4145, CVE-2016-4146, CVE-2016-4147, CVE-2016-4148,
    CVE-2016-4149, CVE-2016-4150, CVE-2016-4151, CVE-2016-4152,
    CVE-2016-4153, CVE-2016-4154, CVE-2016-4155, CVE-2016-4156,
    CVE-2016-4166, CVE-2016-4171.
* Mon Jun  6 2016 Alexei Sorokin <sor.alexei@meowr.ru>
- Security update to version 11.2.202.621 (bsc#979422):
  * APSA16-02, CVE-2016-4117.
- Reference source links for the plugin.
* Sun Apr 10 2016 Alexei Sorokin <sor.alexei@meowr.ru>
- Security update to version 11.2.202.616 (bsc#974209):
  * APSA16-01, CVE-2016-1019.
* Sat Mar 19 2016 Alexei Sorokin <sor.alexei@meowr.ru>
- Security update to version 11.2.202.577 (bsc#970547):
  * APSB16-08, CVE-2016-0960, CVE-2016-0961, CVE-2016-0962,
    CVE-2016-0963, CVE-2016-0986, CVE-2016-0987, CVE-2016-0988,
    CVE-2016-0989, CVE-2016-0990, CVE-2016-0991, CVE-2016-0992,
    CVE-2016-0993, CVE-2016-0994, CVE-2016-0995, CVE-2016-0996,
    CVE-2016-0997, CVE-2016-0998, CVE-2016-0999, CVE-2016-1000,
    CVE-2016-1001, CVE-2016-1002, CVE-2016-1005, CVE-2016-1010.
* Thu Feb 11 2016 Alexei Sorokin <sor.alexei@meowr.ru>
- Security update to version 11.2.202.569 (bsc#965901):
  * APSB16-04, CVE-2016-0964, CVE-2016-0965, CVE-2016-0966,
    CVE-2016-0967, CVE-2016-0968, CVE-2016-0969, CVE-2016-0970,
    CVE-2016-0971, CVE-2016-0972, CVE-2016-0973, CVE-2016-0974,
    CVE-2016-0975, CVE-2016-0976, CVE-2016-0977, CVE-2016-0978,
    CVE-2016-0979, CVE-2016-0980, CVE-2016-0981, CVE-2016-0982,
    CVE-2016-0983, CVE-2016-0984, CVE-2016-0985.
* Tue Dec 29 2015 Alexei Sorokin <sor.alexei@meowr.ru>
- Security update to version 11.2.202.559 (bsc#960317):
  * APSB16-01, CVE-2015-8459, CVE-2015-8460, CVE-2015-8634,
    CVE-2015-8635, CVE-2015-8636, CVE-2015-8638, CVE-2015-8639,
    CVE-2015-8640, CVE-2015-8641, CVE-2015-8642, CVE-2015-8643,
    CVE-2015-8644, CVE-2015-8645, CVE-2015-8646, CVE-2015-8647,
    CVE-2015-8648, CVE-2015-8649, CVE-2015-8650, CVE-2015-8651.
* Tue Dec  8 2015 Alexei Sorokin <sor.alexei@meowr.ru>
- Security update to version 11.2.202.554 (bsc#958324):
  * APSB15-32, CVE-2015-8045, CVE-2015-8047, CVE-2015-8048,
    CVE-2015-8049, CVE-2015-8050, CVE-2015-8055, CVE-2015-8056,
    CVE-2015-8057, CVE-2015-8058, CVE-2015-8059, CVE-2015-8060,
    CVE-2015-8061, CVE-2015-8062, CVE-2015-8063, CVE-2015-8064,
    CVE-2015-8065, CVE-2015-8066, CVE-2015-8067, CVE-2015-8068,
    CVE-2015-8069, CVE-2015-8070, CVE-2015-8071, CVE-2015-8401,
    CVE-2015-8402, CVE-2015-8403, CVE-2015-8404, CVE-2015-8405,
    CVE-2015-8406, CVE-2015-8407, CVE-2015-8408, CVE-2015-8409,
    CVE-2015-8410, CVE-2015-8411, CVE-2015-8412, CVE-2015-8413,
    CVE-2015-8414, CVE-2015-8415, CVE-2015-8416, CVE-2015-8417,
    CVE-2015-8418, CVE-2015-8419, CVE-2015-8420, CVE-2015-8421,
    CVE-2015-8422, CVE-2015-8423, CVE-2015-8424, CVE-2015-8425,
    CVE-2015-8426, CVE-2015-8427, CVE-2015-8428, CVE-2015-8429,
    CVE-2015-8430, CVE-2015-8431, CVE-2015-8432, CVE-2015-8433,
    CVE-2015-8434, CVE-2015-8435, CVE-2015-8436, CVE-2015-8437,
    CVE-2015-8438, CVE-2015-8439, CVE-2015-8440, CVE-2015-8441,
    CVE-2015-8442, CVE-2015-8443, CVE-2015-8444, CVE-2015-8445,
    CVE-2015-8446, CVE-2015-8447, CVE-2015-8448, CVE-2015-8449,
    CVE-2015-8450, CVE-2015-8451, CVE-2015-8452, CVE-2015-8453,
    CVE-2015-8454, CVE-2015-8455.
* Tue Nov 10 2015 Alexei Sorokin <sor.alexei@meowr.ru>
- Security update to version 11.2.202.548:
  * APSB15-28, CVE-2015-7651, CVE-2015-7652, CVE-2015-7653,
    CVE-2015-7654, CVE-2015-7655, CVE-2015-7656, CVE-2015-7657,
    CVE-2015-7658, CVE-2015-7660, CVE-2015-7661, CVE-2015-7663,
    CVE-2015-8042, CVE-2015-8043, CVE-2015-8044, CVE-2015-8046.
* Tue Oct 27 2015 Alexei Sorokin <sor.alexei@meowr.ru>
- Security update to version 11.2.202.540:
  * APSB15-27, CVE-2015-7645, CVE-2015-7647, CVE-2015-7648.
- Enable standalone plugin for x86-64 version of this package.
- Remove flash-player-kde4 package: doesn't support Plasma5.
- Remove kcm_adobe_flash_player.desktop.patch.
- Update icon cache in flash-player-gnome package.
- Remove support for old versions of openSUSE.
- Remove unused mms.cfg and update.sh.
- Spec cleanup.
* Thu Mar 12 2015 sbrabec@suse.com
- Security update to 11.2.202.451 (bsc#922033):
  * APSB15-05, CVE-2015-0332, CVE-2015-0333, CVE-2015-0334,
    CVE-2015-0335, CVE-2015-0336, CVE-2015-0337, CVE-2015-0338,
    CVE-2015-0339, CVE-2015-0340, CVE-2015-0341, CVE-2015-0342
- Improve update.sh:
  * format changes
  * support for reuse of update data in other directory
* Fri Feb  6 2015 sbrabec@suse.com
- Security update to 11.2.202.442 (bsc#915918):
  * APSB15-04, CVE-2015-0313, CVE-2015-0314, CVE-2015-0315,
    CVE-2015-0316, CVE-2015-0317, CVE-2015-0318, CVE-2015-0319,
    CVE-2015-0320, CVE-2015-0321, CVE-2015-0322, CVE-2015-0323,
    CVE-2015-0324, CVE-2015-0325, CVE-2015-0326, CVE-2015-0327,
    CVE-2015-0328, CVE-2015-0329, CVE-2015-0330, CVE-2015-0331
- Re-enable flashplayer executable binary for i386.
* Mon Jan 26 2015 sbrabec@suse.com
- Security update to 11.2.202.440 (bsc#914463):
  * APSA15-01, CVE-2015-0311
- Update of flashplayer (executable binary) for i386 is not
  available. Disabled!
* Thu Jan 22 2015 sbrabec@suse.com
- Security update to 11.2.202.438 (bsc#914333):
  * APSB15-02, CVE-2015-0310
* Wed Jan 14 2015 sbrabec@suse.com
- Security update to 11.2.202.429 (bsc#913057):
  * APSB15-01, CVE-2015-0301, CVE-2015-0302, CVE-2015-0303,
    CVE-2015-0304, CVE-2015-0305, CVE-2015-0306, CVE-2015-0307,
    CVE-2015-0308, CVE-2015-0309.
- Disable flash player on machines without SSE2 (bnc#856386).
- Remove outdated README and keep only up-to-date readme.txt.
* Thu Dec 11 2014 sbrabec@suse.com
- Security update to 11.2.202.425 (bsc#909219):
  * APSB14-27, CVE-2014-0580, CVE-2014-0587, CVE-2014-8443,
    CVE-2014-9162, CVE-2014-9163, CVE-2014-9164
* Wed Nov 26 2014 sbrabec@suse.com
- Security update to 11.2.202.424 (bnc#907257):
  * APSB14-26, CVE-2014-8439
* Wed Nov 12 2014 sbrabec@suse.com
- Security update to 11.2.202.418 (bnc#905032):
  * APSB14-24, CVE-2014-0573, CVE-2014-0574, CVE-2014-0576,
    CVE-2014-0577, CVE-2014-0581, CVE-2014-0582, CVE-2014-0583,
    CVE-2014-0584, CVE-2014-0585, CVE-2014-0586, CVE-2014-0588,
    CVE-2014-0589, CVE-2014-0590, CVE-2014-8437, CVE-2014-8438,
    CVE-2014-8440, CVE-2014-8441, CVE-2014-8442
* Wed Oct 15 2014 sbrabec@suse.com
- Security update to 11.2.202.411 (bnc#901334):
  * APSB14-22, CVE-2014-0569 (ZDI-14-365), CVE-2014-0564,
    CVE-2014-0558
* Tue Sep  9 2014 sbrabec@suse.com
- Security update to 11.2.202.406 (bnc#895856):
  * APSB14-21, CVE-2014-0547, CVE-2014-0548, CVE-2014-0549,
    CVE-2014-0550, CVE-2014-0551, CVE-2014-0552, CVE-2014-0553,
    CVE-2014-0554, CVE-2014-0555, CVE-2014-0556, CVE-2014-0557,
    CVE-2014-0559
* Wed Aug 13 2014 sbrabec@suse.com
- Security update to 11.2.202.400 (bnc#891688):
  * APSB14-18, CVE-2014-0538, CVE-2014-0540, CVE-2014-0541,
    CVE-2014-0542, CVE-2014-0543, CVE-2014-0544, CVE-2014-0545
* Wed Jul  9 2014 sbrabec@suse.com
- Security update to 11.2.202.394 (bnc#886472):
  * APSB14-17, CVE-2014-0537, CVE-2014-0539, CVE-2014-4671
- License update (LICENSE -> Flash%%20Player_14.0.pdf).
* Wed Jun 11 2014 sbrabec@suse.com
- Security update to 11.2.202.378 (bnc#882187, Redhat#1107822,
  Redhat#1107823):
  * APSB14-16, CVE-2014-0531, CVE-2014-0532, CVE-2014-0533,
    CVE-2014-0534, CVE-2014-0535, CVE-2014-0536
- Contents of flashplayer_11_sa.i386.tar.gz changed:
  spec file updated, supplementary script (update.sh) updated.
  Now it accepts both forms of this file seen in past.
* Wed May 14 2014 sbrabec@suse.com
- Security update to 11.2.202.359 (bnc#877649):
  * APSB14-14, CVE-2014-0516, CVE-2014-0517, CVE-2014-0518,
    CVE-2014-0519, CVE-2014-0520
* Tue Apr 29 2014 sbrabec@suse.com
- Security update to 11.2.202.356 (bnc#875577):
  * APSB14-13, CVE-2014-0515
* Thu Apr 10 2014 sbrabec@suse.com
- Security update to 11.2.202.350: (bnc#872692)
  * APSB14-09, CVE-2014-0506, CVE-2014-0507, CVE-2014-0508,
    CVE-2014-0509
* Wed Mar 12 2014 sbrabec@suse.com
- Security update to 11.2.202.346: (bnc#867808)
  * APSB14-08, CVE-2014-0503, CVE-2013-0504
* Fri Feb 21 2014 sbrabec@suse.com
- Security update to 11.2.202.341: (bnc#865021)
  * APSB14-07, CVE-2014-0498 CVE-2014-0499 CVE-2014-0502
- Contents of flashplayer_11_sa.i386.tar.gz changed back:
  spec file updated, supplementary script (update.sh) updated.
* Wed Feb  5 2014 sbrabec@suse.com
- Security update to 11.2.202.336: (bnc#862288)
  * APSB14-04, CVE-2014-0497
- Contents of flashplayer_11_sa.i386.tar.gz changed:
  spec file updated, supplementary script (update.sh) updated.
* Wed Jan 15 2014 sbrabec@suse.com
- Security update to 11.2.202.335: (bnc#858822)
  * APSB14-02, CVE-2014-0491, CVE-2014-0492
* Thu Dec 12 2013 sbrabec@suse.com
- Security update to 11.2.202.332: (bnc#854881)
  * APSB13-28, CVE-2013-5331, CVE-2013-5332
  * Prevents possible remote code execution!
* Wed Nov 13 2013 sbrabec@suse.com
- Security update to 11.2.202.327: (bnc#850220)
  * APSB13-26, CVE-2013-5329, CVE-2013-5330
- Supplementary script (update.sh) update:
  * Update to the new web pages layout.
  * Use original .tar.gz files released by Adobe.
* Thu Sep 12 2013 sbrabec@suse.com
- Update to 11.2.202.310: (bnc#839897)
  * APSB13-21, CVE-2013-3361, CVE-2013-3362, CVE-2013-3363,
    CVE-2013-5324
* Wed Jul 10 2013 sbrabec@suse.com
- Update to 11.2.202.297: (bnc#828810)
  * APSB13-17, CVE-2013-3344, CVE-2013-3345, CVE-2013-3347
* Wed Jun 12 2013 sbrabec@suse.com
- Update to 11.2.202.291: (bnc#824512)
  * APSB13-16, CVE-2013-3343
* Wed May 15 2013 burnus@net-b.de
- Update to 11.2.202.285: (bnc#819916)
  * CVE-2013-2728, CVE-2013-3324, CVE-2013-3325, CVE-2013-3326,
    CVE-2013-3327, CVE-2013-3328, CVE-2013-3329, CVE-2013-3330,
    CVE-2013-3331, CVE-2013-3332, CVE-2013-3333, CVE-2013-3334,
    CVE-2013-3335
* Wed Apr 10 2013 sbrabec@suse.com
- Update to 11.2.202.280: (bnc#814635)
  * APSB13-11, CVE-2013-1378, CVE-2013-1379, CVE-2013-1380,
    CVE-2013-2555
* Thu Mar 14 2013 burnus@net-b.de
- Use "Licence: SUSE-NonFree" in the spec file.
* Tue Mar 12 2013 sbrabec@suse.com
- Update to 11.2.202.275: (bnc#808973)
  * APSB13-09, CVE-2013-0646, CVE-2013-0650, CVE-2013-1371,
    CVE-2013-1375
* Wed Feb 27 2013 sbrabec@suse.com
- Update to 11.2.202.273: (bnc#806415)
  * APSB13-08, CVE-2013-0504, CVE-2013-0643, CVE-2013-0648
* Wed Feb 13 2013 sbrabec@suse.com
- Update to 11.2.202.270: (bnc#803485)
  * APSB13-05, CVE-2013-1372, CVE-2013-0645, CVE-2013-1373,
    CVE-2013-1369, CVE-2013-1370, CVE-2013-1366, CVE-2013-0649,
    CVE-2013-1365, CVE-2013-1374, CVE-2013-1368, CVE-2013-0642,
    CVE-2013-0644, CVE-2013-0647, CVE-2013-1367, CVE-2013-0639,
    CVE-2013-0638, CVE-2013-0637
* Fri Feb  8 2013 sbrabec@suse.com
- Update to 11.2.202.262: (bnc#802809)
  * APSB13-04, CVE-2013-0633, CVE-2013-0634
* Wed Jan  9 2013 dmueller@suse.com
- Update to 11.2.202.261: (bnc#797442)
  * CVE-2013-0630
* Wed Dec 12 2012 dmueller@suse.com
- Update to 11.2.202.258: (bnc#794062):
  * CVE-2012-5676, CVE-2012-5677, CVE-2012-5678
* Tue Nov  6 2012 dmueller@suse.com
- Update to 11.2.202.251 (bnc#788450):
  * CVE-2012-5274, CVE-2012-5275, CVE-2012-5276, CVE-2012-5277,
  CVE-2012-5278, CVE-2012-5279, CVE-2012-5280
* Tue Oct  9 2012 dmueller@suse.com
- Update to 11.2.202.243: (bnc#784168)
  * CVE-2012-5248, CVE-2012-5249, CVE-2012-5250, CVE-2012-5251,
  CVE-2012-5252, CVE-2012-5253, CVE-2012-5254, CVE-2012-5255,
  CVE-2012-5256, CVE-2012-5257, CVE-2012-5258, CVE-2012-5259,
  CVE-2012-5260, CVE-2012-5261, CVE-2012-5262, CVE-2012-5263,
  CVE-2012-5264, CVE-2012-5265, CVE-2012-5266, CVE-2012-5267,
  CVE-2012-5268, CVE-2012-5269, CVE-2012-5270, CVE-2012-5271,
  CVE-2012-5272
* Wed Aug 15 2012 dmueller@suse.com
- Update to 11.2.202.238: (bnc#775986):
  * CVE-2012-1535
* Fri Jun  8 2012 dmueller@suse.com
- Update to 11.2.202.236: (bnc#766241)
  * CVE-2012-2034, CVE-2012-2035, CVE-2012-2036, CVE-2012-2037,
    CVE-2012-2038, CVE-2012-2039, CVE-2012-2040)
- remove mms.cfg again, causes crashes for many users (bnc#761975)
* Fri May  4 2012 dmueller@suse.com
- Update to 11.2.202.235: (bnc#760777)
  * CVE-2012-0779
* Wed Apr 25 2012 anixx@opensuse.org
- add file mms.cfg to fix inverted colors when using nvidia drivers
  (bnc#758645)
* Tue Apr 17 2012 dmueller@suse.com
- Update to 11.2.202.233: (bnc#757428):
  * This release addresses a printing issue that was found
  in the previous version of Flash Player.
* Thu Mar 29 2012 dmueller@suse.com
- Update to 11.2.202.228: (bnc#754689)
  http://www.adobe.com/support/security/bulletins/apsb12-07.html
  * CVE-2012-0773
* Tue Mar  6 2012 dmueller@suse.com
- Update to 11.1.102.63: (bnc#750614)
  http://www.adobe.com/support/security/bulletins/apsb12-05.html
  * CVE-2012-0768, CVE-2012-0769
* Thu Feb 16 2012 meissner@suse.com
- Update to 11.1.102.62: (bnc#747297)
  https://www.adobe.com/support/security/bulletins/apsb12-03.html
  CVEs fixed: CVE-2012-0751, CVE-2012-0752, CVE-2012-0753, CVE-2012-0754,
  CVE-2012-0755, CVE-2012-0756, CVE-2012-0767
* Fri Jan 27 2012 dmueller@suse.de
- fix provides/obsoletes causing arch-conflict
* Tue Jan 24 2012 ro@suse.de
- fix macros in specfile
* Mon Jan 16 2012 dmueller@suse.de
- provide/obsolete also libflashsupport for sled11-sp1
- add compat macros that are necessary after the "spec-cleaner run"
* Wed Dec 28 2011 asterios.dramis@gmail.com
- Added a patch (kcm_adobe_flash_player.desktop.patch) to make the KCM module
  X-KDE-System-Settings-Parent-Category entry compatible with newer KDE
  versions in order to not showup in the "Lost and Found" section.
- Spec-file updates:
  * Spec file cleanup based also on spec-cleaner run.
* Tue Nov 15 2011 dmueller@suse.de
- remove standalone binary for x86_64 as long as it is not updated
* Fri Nov 11 2011 dmueller@suse.com
- Update to 11.1.102.55 (bnc#729797):
  * CVE-2011-2445, CVE-2011-2450, CVE-2011-2451, CVE-2011-2452,
  CVE-2011-2453, CVE-2011-2454, CVE-2011-2455, CVE-2011-2456,
  CVE-2011-2457, CVE-2011-2458, CVE-2011-2459, CVE-2011-2460
* Tue Oct  4 2011 dmueller@suse.de
- update to 11.0.1.152 (bnc#722151):
  * See http://kb2.adobe.com/cps/919/cpsid_91932.html
  for details.
- enable building for x86_64
* Wed Sep 21 2011 dmueller@suse.com
- Update to 10.3.183.10: (bnc#719400):
  * Update to Flash Player that addresses a zero-day vulnerability.
* Wed Sep 21 2011 dmueller@suse.de
- update license to 10.3 EULA (bnc#575642)
* Fri Aug 26 2011 dmueller@suse.de
- Update to 10.3.183.7: (bnc#714365):
  * Shared library/gotoAndPlay() or gotoAndStop() bug
  * Textfields are displaying text vertically in 10.3.183.5 release
  * Massive Animation Slowdown following install of FP 10.3.183.5
  * Flash player 10.3 displays a black screen (2943064)
  * Sound repeating and building up bug (2941616)
  * Flash applications at certain websites (http://www.justin.tv,
  http://heylenmichel.de) now load correctly (2939645, 2944081)
* Wed Aug 10 2011 dmueller@suse.de
- Update to 10.3.183.5: (bnc#711427):
  * CVE-2011-2130, CVE-2011-2134, CVE-2011-2135, CVE-2011-2136,
    CVE-2011-2137,  CVE-2011-2138,  CVE-2011-2139,  CVE-2011-2140,
    CVE-2011-2414,  CVE-2011-2415,  CVE-2011-2416,  CVE-2011-2417,
    CVE-2011-2425
* Mon Jul  4 2011 dmueller@suse.de
- Update to 10.3.181.34: (bnc#703618):
  * Adobe Flash Player 10.3.181.34 addresses compatibility
  issues with some content using cross-domain policy files.
* Tue Jun 14 2011 dmueller@suse.de
- Update to 10.3.181.26: (bnc#699942):
  * CVE-2011-2110
* Mon Jun  6 2011 dmueller@suse.de
- Update to 10.3.181.22: (bnc#698261)
  * CVE-2011-2107
* Fri May 13 2011 dmueller@suse.de
- add missing requires
* Fri May 13 2011 dmueller@suse.de
- split kde4 and gnome subpackages
* Thu May 12 2011 dmueller@suse.de
- Update to 10.3.181.14 (bnc#693573):
  * CVE-2011-0589, CVE-2011-0618, CVE-2011-0619, CVE-2011-0620,
    CVE-2011-0621, CVE-2011-0622, CVE-2011-0623, CVE-2011-0624,
    CVE-2011-0625, CVE-2011-0626, CVE-2011-0627
  * Important security and bugfix enhancements
    http://www.adobe.com/go/apsb11-12
  * Acoustic echo cancellation
  * Simplified local storage management
  * Local settings manager
* Fri Apr 15 2011 dmueller@suse.de
- Update to 10.2.159.1: (bnc#686818):
  * CVE-2011-0611
* Mon Mar 28 2011 dmueller@suse.de
- update standalone player (bnc#682902)
* Mon Mar 21 2011 dmueller@suse.de
- Update to 10.2.153.1: (bnc#679672)
  * CVE-2011-0609
* Wed Feb  9 2011 meissner@suse.de
- updated to 10.2.152.26 (bnc#670531):
  * CVE-2011-0558, CVE-2011-0559, CVE-2011-0560, CVE-2011-0561,
  * CVE-2011-0571, CVE-2011-0572, CVE-2011-0573, CVE-2011-0574,
  * CVE-2011-0575, CVE-2011-0577, CVE-2011-0578, CVE-2011-0607,
  * CVE-2011-0608
  * http://www.adobe.com/support/security/bulletins/apsb11-02.html
* Thu Nov  4 2010 dmueller@suse.de
- update to 10.1.102.64  (bnc#650145):
  * CVE-2010-3654
* Mon Sep 20 2010 dmueller@suse.de
- update to 10.1.85.3 (bnc#639541):
  * CVE-2010-2884
* Tue Aug 10 2010 dmueller@suse.de
- update to 10.1.82.76 (bnc#630108):
  * CVE-2010-0209, CVE-2010-2188, CVE-2010-2213, CVE-2010-2214,
  CVE2010-2215, CVE-2010-2216
* Fri Jun 11 2010 dmueller@suse.de
- update to 10.1.53.64 (bnc#612063):
  * CVE-2008-4546, CVE-2009-3793, CVE-2010-1297, CVE-2010-2160,
  CVE-2010-2161, CVE-2010-2162, CVE-2010-2163, CVE-2010-2164,
  CVE-2010-2165, CVE-2010-2166, CVE-2010-2167, CVE-2010-2169,
  CVE-2010-2170, CVE-2010-2171, CVE-2010-2172, CVE-2010-2173,
  CVE-2010-2174, CVE-2010-2175, CVE-2010-2176, CVE-2010-2177,
  CVE-2010-2178, CVE-2010-2179, CVE-2010-2180, CVE-2010-2181,
  CVE-2010-2182, CVE-2010-2183, CVE-2010-2184, CVE-2010-2185,
  CVE-2010-2186, CVE-2010-2187, CVE-2010-2188, CVE-2010-2189
* Sat Feb 13 2010 dmueller@suse.de
- update to 10.0.45.2 (bnc#578997):
  * CVE-2010-0186, CVE-2010-0187
* Wed Dec 16 2009 dmueller@suse.de
- also provide libflashsupport, otherwise patch update
  complains about the obsolete
* Tue Dec 15 2009 lnussel@suse.de
- don't obsolete libflashsupport for now (bnc#560259)
* Wed Dec  9 2009 dmueller@suse.de
- update to 10.0.42.34 (bnc#560259):
  * CVE-2009-3794, CVE-2009-3796, CVE-2009-3797, CVE-2009-3798,
  CVE-2009-3799, CVE-2009-3800, CVE-2009-3951
* Fri Nov  6 2009 crrodriguez@opensuse.org
- flash player makes no sound in x86_64 if libasound.so.2
  is not installed and pulseaudio is disabled.
* Thu Oct  1 2009 sreeves@novell.com
- fix bnc#539656 - obsolete libflashsupport
* Thu Aug  6 2009 dmueller@suse.de
- also provide flash-plugin
* Fri Jul 31 2009 dmueller@suse.de
- update to 10.0.32.18 (bnc#524508):
  * CVE-2009-1862, CVE-2009-0901, CVE-2009-2395, CVE-2009-2493,
  CVE-2009-1863, CVE-2009-1864, CVE-2009-1865, CVE-2009-1866,
  CVE-2009-1867, CVE-2009-1868, CVE-2009-1869, CVE-2009-1870
* Wed Jun 17 2009 beineri@opensuse.org
- fix capitalization of start menu entry
* Wed Feb 25 2009 dmueller@suse.de
- update to 10.0.22.87 (bnc#476907):
  * CVE-2009-0519, CVE-2009-0520,CVE-2009-0522, CVE-2009-0114
  CVE-2009-0521
* Thu Dec 18 2008 dmueller@suse.de
- update to 10.0.15.3 (bnc#458573):
  CVE-2008-5499
* Wed Nov 12 2008 dmueller@suse.de
- require libcurl.so.4 (bnc#443772)
* Mon Nov  3 2008 dmueller@suse.de
- strip rpath from standalone player as well
* Mon Oct 27 2008 ro@suse.de
- fix typo in specfile
* Wed Oct 15 2008 dmueller@suse.de
- update to 10.0.12.36 (bnc#435201):
  * fixes for CVE-2007-6243, CVE-2008-3873, CVE-2007-4324,
  CVE-2008-4401, CVE-2008-4503
  * http://www.adobe.com/products/flashplayer/
* Wed Apr  9 2008 dmueller@suse.de
- update to 9.0.124.0 (bnc#376639)
  * CVE-2007-6637
* Tue Dec  4 2007 dmueller@suse.de
- update to 9.0.115.0 (#310213)
* Wed Jul 11 2007 dmueller@suse.de
- update to 9.0.48.0 (#257905,
  CVE-2007-3456, CVE-2007-3457, CVE-2007-2022)
* Thu Apr 12 2007 dmueller@suse.de
- add standalone flash player binary (#263332)
* Wed Jan 17 2007 dmueller@suse.de
- update to 9.0.31.0 (FATE #301150)
* Thu Dec  7 2006 coolo@suse.de
- update to 7.0.69.0 (CVE-2006-5330, #213291)
* Wed Sep 13 2006 dmueller@suse.de
- update to 7.0.68.0 (CVE-2006-3311, CVE-2006-3587, CVE-2006-3588,
  [#205382])
* Thu Mar 16 2006 ltinkl@suse.cz
- fix #158227 - VUL-0: vulnerability in flash-player
  (Flash installer updated to 7.0.63.0)
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Wed Sep 28 2005 dmueller@suse.de
- add norootforbuild
* Mon Jul 26 2004 clahey@suse.de
- Update to version 7.0.25.0.
* Wed Mar 31 2004 aj@suse.de
- Update to version 6.0r81:
  * flash scripting fixes
  * video quality and playback speed improvements
  * performance improvements
* Fri Jun 20 2003 ro@suse.de
- don't include dir in filelist, is in filesystem package now
* Sun Mar 16 2003 ro@suse.de
- security update to version 6.0r79
* Mon Feb 24 2003 ro@suse.de
- created (obsoletes old netscape-plugins package)
